# ev3sim

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-7-orange.svg?style=flat-square)](#contributors-)<!-- ALL-CONTRIBUTORS-BADGE:END -->
![Python test suite](https://github.com/MelbourneHighSchoolRobotics/ev3sim/workflows/Python%20test%20suite/badge.svg)
![Docs Check](https://github.com/MelbourneHighSchoolRobotics/ev3sim/workflows/Docs%20Check/badge.svg)

## Getting started

To get up and running with the simulator, see the docs: https://ev3sim.mhscsr.club

## Problems

Find any issues with the simulator? Feel free to make an issue here: https://github.com/MelbourneHighSchoolRobotics/ev3sim/issues

## Contributing

To contribute to ev3sim, see the contributing page of the docs: https://ev3sim.mhscsr.club/contributing

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://pdrew.com/"><img src="https://avatars2.githubusercontent.com/u/10608341?v=4" width="100px;" alt=""/><br /><sub><b>Peter Drew</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=peter-drew" title="Code">💻</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=peter-drew" title="Documentation">📖</a> <a href="#eventOrganizing-peter-drew" title="Event Organizing">📋</a> <a href="#ideas-peter-drew" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://angus.ws"><img src="https://avatars1.githubusercontent.com/u/13267947?v=4" width="100px;" alt=""/><br /><sub><b>Angus Trau</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=angustrau" title="Code">💻</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=angustrau" title="Documentation">📖</a> <a href="#ideas-angustrau" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-angustrau" title="Answering Questions">💬</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/pulls?q=is%3Apr+reviewed-by%3Aangustrau" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=angustrau" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://dalordish.github.io"><img src="https://avatars2.githubusercontent.com/u/5959205?v=4" width="100px;" alt=""/><br /><sub><b>Richard</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=Dalordish" title="Code">💻</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=Dalordish" title="Documentation">📖</a> <a href="#infra-Dalordish" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#ideas-Dalordish" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/pulls?q=is%3Apr+reviewed-by%3ADalordish" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/jtbui20"><img src="https://avatars2.githubusercontent.com/u/29140560?v=4" width="100px;" alt=""/><br /><sub><b>James Bui</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=jtbui20" title="Code">💻</a> <a href="#design-jtbui20" title="Design">🎨</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/pulls?q=is%3Apr+reviewed-by%3Ajtbui20" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/platy11"><img src="https://avatars0.githubusercontent.com/u/17060983?v=4" width="100px;" alt=""/><br /><sub><b>Max</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=platy11" title="Code">💻</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/pulls?q=is%3Apr+reviewed-by%3Aplaty11" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/glipR"><img src="https://avatars1.githubusercontent.com/u/37640160?v=4" width="100px;" alt=""/><br /><sub><b>Jackson Goerner</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=glipR" title="Code">💻</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=glipR" title="Documentation">📖</a> <a href="#maintenance-glipR" title="Maintenance">🚧</a> <a href="#ideas-glipR" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-glipR" title="Answering Questions">💬</a> <a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/pulls?q=is%3Apr+reviewed-by%3AglipR" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/Juicymangoes123"><img src="https://avatars0.githubusercontent.com/u/53684212?v=4" width="100px;" alt=""/><br /><sub><b>Juicymangoes123</b></sub></a><br /><a href="https://github.com/MelbourneHighSchoolRobotics/ev3sim/commits?author=Juicymangoes123" title="Documentation">📖</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
